@@ -86,42 +86,55 @@ sub _initialize {
     my $write_watch_r = \do { $self->{'_write_watch'} = undef };
 
     my $cb_r;
+
+    my $clear_watchers_cr = sub {
+        undef $$cb_r;
+        undef $$read_watch_r;
+        undef $$write_watch_r;
+    };
+
     my $cb = sub {
-        if ( $dbus->initialize() ) {
-            undef $$cb_r;
-            undef $$read_watch_r;
-            undef $$write_watch_r;
-            $y->();
-        }
-
-        # It seems unlikely that we’d need a write watch here.
-        # But just in case …
-        elsif ($dbus->init_pending_send()) {
-            $$write_watch_r ||= do {
-
+        my $ok = eval {
+            if ( $dbus->initialize() ) {
+                $clear_watchers_cr->();
+                $y->();
+            }
+            else {
                 my $current_sub = $$cb_r;
 
-                AnyEvent->io(
-                    fh => $fileno,
-                    poll => 'w',
-                    cb => $current_sub,
-                );
-            };
-        }
-        else {
-            undef $$write_watch_r;
+                if ($dbus->init_pending_send()) {
+                    $$write_watch_r ||= AnyEvent->io(
+                        fh => $fileno,
+                        poll => 'w',
+                        cb => $current_sub,
+                    );
+                }
+                else {
+                    undef $$write_watch_r;
+
+                    $$read_watch_r ||= AnyEvent->io(
+                        fh => $fileno,
+                        poll => 'r',
+                        cb => $current_sub,
+                    );
+                }
+            }
+
+            1;
+        };
+
+        if (!$ok) {
+            $clear_watchers_cr->();
+            $n->($@);
         }
     };
 
     $cb_r = \$cb;
 
-    $$read_watch_r = AnyEvent->io(
-        fh => $fileno,
-        poll => 'r',
-        cb => $cb,
-    );
+    # Postpone in order to give the caller time to set up promises, etc.
+    AnyEvent::postpone( sub { $cb->() } );
 
-    $cb->();
+    return;
 }
 
 sub _flush_send_queue {
@@ -145,23 +158,42 @@ sub _set_watches_and_create_messenger {
 
     my $fileno = $dbus->fileno();
 
+    my $write_watch_sr = \$self->{'_write_watch'};
+
+    my $flush_cr = sub {
+        _flush_send_queue( $dbus, $fileno, $write_watch_sr );
+    };
+
     if (!$self->{'_read_watch'}) {
 
-        my $watch = undef;
-        _flush_send_queue( $dbus, $fileno, \$watch );
+        $flush_cr->();
 
-        $self->{'_send_watch_ref'} = \$watch;
+        $self->{'_read_callback'} = $self->_create_get_message_callback();
 
-        $self->{'_read_watch'} = AnyEvent->io(
-            fh => $fileno,
-            poll => 'r',
-            cb => $self->_create_get_message_callback(),
-        );
+        $self->_resume();
+
+        my $read_watch_sr = \$self->{'_read_watch'};
+
+        $self->{'_give_up_cr'} = sub {
+            $$read_watch_sr = undef;
+        };
     }
 
-    my $watch_sr = $self->{'_send_watch_ref'};
+    return $flush_cr;
+}
 
-    return sub { _flush_send_queue( $dbus, $fileno, $watch_sr ) };
+sub _pause {
+    $_[0]->{'_read_watch'} = undef;
+}
+
+sub _resume {
+    my ($self) = @_;
+
+    $self->{'_read_watch'} ||= AnyEvent->io(
+        fh => $self->{'db'}->fileno(),
+        poll => 'r',
+        cb => $self->{'_read_callback'},
+    );
 }
 
 1;
